@@ -24,8 +24,8 @@ def add(**settings_patches):
                               validate=validate_file_existence)
     with open(ssh_pub_key_path, 'r') as f:
         key_content = f.read().strip()
-    hash_key = hashlib.md5(key_content)[:16]
-    tmp_path = '/tmp/beanstalk-stack/pub_key.{hash}.tmp'.format(hash=hash_key)
+    hash_key = hashlib.md5(key_content).hexdigest()[:16]
+    tmp_path = '/tmp/beanstalk-stack.{hash}.pub.key'.format(hash=hash_key)
 
     @roles('web_servers')
     def add_user_core():
